@@ -2,14 +2,15 @@
 
 #include "qdldl_interface.h" // Include only this solver in the same directory
 
+const char *LINSYS_SOLVER_NAME[] = {
+  "qdldl", "mkl pardiso"
+};
+
 #ifdef ENABLE_MKL_PARDISO
 # include "pardiso_interface.h"
 # include "pardiso_loader.h"
 #endif /* ifdef ENABLE_MKL_PARDISO */
 
-
-#ifndef EMBEDDED
-
 // Load linear system solver shared library
 c_int load_linsys_solver(enum linsys_solver_type linsys_solver) {
   switch (linsys_solver) {
@@ -52,33 +53,23 @@ c_int unload_linsys_solver(enum linsys_solver_type linsys_solver) {
 
 // Initialize linear system solver structure
 // NB: Only the upper triangular part of P is stuffed!
-LinSysSolver* init_linsys_solver(const csc              *P,
-                                 const csc              *A,
-                                 c_float                 sigma,
-                                 c_float                *rho_vec,
-                                 enum linsys_solver_type linsys_solver,
-                                 c_int                   polish) {
+c_int init_linsys_solver(LinSysSolver          **s,
+                         const csc              *P,
+                         const csc              *A,
+                         c_float                 sigma,
+                         const c_float          *rho_vec,
+                         enum linsys_solver_type linsys_solver,
+                         c_int                   polish) {
   switch (linsys_solver) {
   case QDLDL_SOLVER:
-    return (LinSysSolver *)init_linsys_solver_qdldl(P,
-                                                    A,
-                                                    sigma,
-                                                    rho_vec,
-                                                    polish);
+    return init_linsys_solver_qdldl((qdldl_solver **)s, P, A, sigma, rho_vec, polish);
 
 # ifdef ENABLE_MKL_PARDISO
   case MKL_PARDISO_SOLVER:
-    return (LinSysSolver *)init_linsys_solver_pardiso(P, A, sigma, rho_vec,
-                                                      polish);
+    return init_linsys_solver_pardiso((pardiso_solver **)s, P, A, sigma, rho_vec, polish);
 
 # endif /* ifdef ENABLE_MKL_PARDISO */
   default: // QDLDL
-    return (LinSysSolver *)init_linsys_solver_qdldl(P,
-                                                    A,
-                                                    sigma,
-                                                    rho_vec,
-                                                    polish);
+    return init_linsys_solver_qdldl((qdldl_solver **)s, P, A, sigma, rho_vec, polish);
   }
 }
-
-#endif /* ifndef EMBEDDED */
